Crate kcr_acmpca_services_k8s_aws

Crate kcr_acmpca_services_k8s_aws 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the acmpca.services.k8s.aws group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

acmpca.services.k8s.aws/v1alpha1

  • CertificateAuthority
  • CertificateAuthorityActivation
  • Certificate

Modules

v1alpha1