This crate contains kube-rs compatible bindings for Kubernetes custom resources for the acmpca.services.k8s.aws group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
acmpca.services.k8s.aws/v1alpha1
CertificateAuthorityCertificateAuthorityActivationCertificate